//default is lowp (prepended by FF)

varying vec4 v_color;
varying mediump vec2 v_texCoord;
varying mediump vec3 v_position;

uniform sampler2D u_texture;
uniform sampler2D u_texture1;

uniform mediump vec4 u_gridOffset;
uniform vec4 u_lightColors[2];
uniform mediump vec4 u_lightData[2];
uniform mediump vec4 u_screenSize;

const int maxLights = 2;

mediump vec4 CalculateLight(mediump vec3 eyePos, vec4 textureColor, mediump vec3 normal, mediump vec3 lightPos, vec3 lightColor, mediump float lightIntensity, mediump vec3 falloff)
{
    mediump float lightVecDistance = length(lightPos - v_position) * 0.001 * 1.0 / u_screenSize.z; //multiplying with scale factor
    mediump vec3 lightDirection = normalize(lightPos - v_position);

    mediump float intensity = max(0.0, dot(normal, lightDirection)) * lightIntensity;
    
    mediump float attenuation = min(1.0, 1.0 / (falloff.x + (falloff.y * lightVecDistance) + (falloff.z * lightVecDistance * lightVecDistance)));
	mediump vec3 diffuseColor = textureColor.rgb * lightColor;
	
    return vec4((0.5* diffuseColor + 0.5* lightColor) * intensity * attenuation, 0.0);
}

void main() 
{
    mediump vec3 eyePos = vec3(u_screenSize.x * 0.5, u_screenSize.y * 0.5, 1000);

    vec4 textureColor = texture2D(u_texture, v_texCoord) * v_color;
    vec3 normalColor = texture2D(u_texture1, v_texCoord).xyz;

    mediump vec3 normal = normalize(((normalColor * 0.5 - 0.25)) * 4.0);
	
	mediump vec4 color = vec4(0.0,0.0,0.0,0.0);
	mediump vec3 falloffDynamicLights = vec3(0.1, .5, 100.0);
	
	mediump float dynamicLightHeight = 70.0 * u_screenSize.z;

    for(int i = 0; i < maxLights; i++) 
	{
		color += CalculateLight(
			eyePos,
			textureColor,
			normal,
			vec3(u_lightData[i][0], u_lightData[i][1], dynamicLightHeight),
			u_lightColors[i].rgb, 
			u_lightData[i][3],
			falloffDynamicLights
		);	
	}

    gl_FragColor = textureColor + color;
}